@@ -5,14 +5,13 @@ from helper_functions import download_test_data, find_nearest_latlon
 from polytope_feature.datacube.transformations.datacube_mappers.mapper_types.healpix import (
     HealpixGridMapper,
 )
-from polytope_feature.engine.hullslicer import HullSlicer
 from polytope_feature.polytope import Polytope, Request
 from polytope_feature.shapes import Box, Select
 
 
 class TestHealpixGrid:
     def setup_method(self, method):
-        nexus_url = "https://get.ecmwf.int/test-data/polytope/test-data/healpix.grib"
+        nexus_url = "https://sites.ecmwf.int/repository/polytope/test-data/healpix.grib"
         download_test_data(nexus_url, "healpix.grib")
 
         ds = data.from_source("file", "./tests/data/healpix.grib")
@@ -30,10 +29,8 @@ class TestHealpixGrid:
             ],
             "compressed_axes_config": ["longitude", "latitude", "step", "time", "isobaricInhPa", "valid_time"],
         }
-        self.slicer = HullSlicer()
         self.API = Polytope(
             datacube=self.latlon_array,
-            engine=self.slicer,
             options=self.options,
         )
 
