@@ -3,26 +3,23 @@ import pytest
 from earthkit import data
 from helper_functions import download_test_data
 
-from polytope_feature.engine.hullslicer import HullSlicer
 from polytope_feature.polytope import Polytope, Request
 from polytope_feature.shapes import Box, Select
 
 
 class TestSlicingEra5Data:
     def setup_method(self, method):
-        nexus_url = "https://get.ecmwf.int/test-data/polytope/test-data/era5-levels-members.grib"
+        nexus_url = "https://sites.ecmwf.int/repository/polytope/test-data/era5-levels-members.grib"
         download_test_data(nexus_url, "era5-levels-members.grib")
 
         ds = data.from_source("file", "./tests/data/era5-levels-members.grib")
         array = ds.to_xarray(engine="cfgrib").isel(step=0).t
-        self.slicer = HullSlicer()
         options = {
             "axis_config": [{"axis_name": "latitude", "transformations": [{"name": "reverse", "is_reverse": True}]}],
             "compressed_axes_config": ["number", "time", "latitude", "longitude", "step", "isobaricInhPa"],
         }
         self.API = Polytope(
             datacube=array,
-            engine=self.slicer,
             options=options,
         )
 
